Struct xfs::ExtentAllocation
[−]
[src]
pub struct ExtentAllocation {
pub allocated_extents: u32,
pub allocated_blocks: u32,
pub freed_extents: u32,
pub freed_blocks: u32,
}Fields
allocated_extents | Number of file system extents allocated over all XFS filesystems. |
allocated_blocks | Number of file system blocks allocated over all XFS filesystems. |
freed_extents | Number of file system extents freed over all XFS filesystems. |
freed_blocks | Number of file system blocks freed over all XFS filesystems. |